@@ -123,9 +123,10 @@ public:
     bool isPaused() const;
     SavePageFormat savePageFormat() const;
     void setSavePageFormat(SavePageFormat format);
-    DownloadType type() const;
+    DownloadType Q_DECL_DEPRECATED type() const;
     DownloadInterruptReason interruptReason() const;
     QString interruptReasonString() const;
+    bool isSavePageDownload() const;
 
 public Q_SLOTS:
     void accept();
